diff --git a/drivers/gpu/drm/i915/display/intel_display.c b/drivers/gpu/drm/i915/display/intel_display.c
index 759479f576d8..5afc5e678844 100644
--- a/drivers/gpu/drm/i915/display/intel_display.c
+++ b/drivers/gpu/drm/i915/display/intel_display.c
@@ -6429,7 +6429,7 @@ int intel_atomic_check(struct drm_device *dev,
 
 		any_ms = true;
 
-		intel_release_dpll_globals(state, crtc);
+		intel_dpll_release(state, crtc);
 	}
 
 	if (any_ms && !check_digital_port_conflicts(state)) {
diff --git a/drivers/gpu/drm/i915/display/intel_dpll.c b/drivers/gpu/drm/i915/display/intel_dpll.c
index eac588566d7c..13a70ef95804 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll.c
+++ b/drivers/gpu/drm/i915/display/intel_dpll.c
@@ -1190,7 +1190,7 @@ static int hsw_crtc_get_dpll_global(struct intel_atomic_state *state,
 	    intel_crtc_has_type(crtc_state, INTEL_OUTPUT_DSI))
 		return 0;
 
-	return intel_reserve_dpll_globals(state, crtc, encoder);
+	return intel_dpll_reserve(state, crtc, encoder);
 }
 
 static int dg2_crtc_compute_clock(struct intel_atomic_state *state,
@@ -1417,7 +1417,7 @@ static int ilk_crtc_get_dpll_global(struct intel_atomic_state *state,
 	if (!crtc_state->has_pch_encoder)
 		return 0;
 
-	return intel_reserve_dpll_globals(state, crtc, NULL);
+	return intel_dpll_reserve(state, crtc, NULL);
 }
 
 static u32 vlv_dpll(const struct intel_crtc_state *crtc_state)
diff --git a/drivers/gpu/drm/i915/display/intel_dpll_mgr.h b/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
index f240018416c7..b6d5a15b8103 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
+++ b/drivers/gpu/drm/i915/display/intel_dpll_mgr.h
@@ -399,11 +399,11 @@ void assert_dpll_global(struct intel_display *display,
 int intel_compute_dpll_globals(struct intel_atomic_state *state,
 			       struct intel_crtc *crtc,
 			       struct intel_encoder *encoder);
-int intel_reserve_dpll_globals(struct intel_atomic_state *state,
-			       struct intel_crtc *crtc,
-			       struct intel_encoder *encoder);
-void intel_release_dpll_globals(struct intel_atomic_state *state,
-				struct intel_crtc *crtc);
+int intel_dpll_reserve(struct intel_atomic_state *state,
+		       struct intel_crtc *crtc,
+		       struct intel_encoder *encoder);
+void intel_dpll_release(struct intel_atomic_state *state,
+			struct intel_crtc *crtc);
 void intel_dpll_unreference_crtc(const struct intel_crtc *crtc,
 				 const struct intel_dpll_global *pll,
 				 struct intel_dpll_state *shared_dpll_state);

diff --git a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
index dd1f2104d5b1..7faf1b2e6399 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
+++ b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
@@ -53,8 +53,8 @@
  * users of a PLL are tracked and that tracking is integrated with the atomic
  * modset interface. During an atomic operation, required PLLs can be reserved
  * for a given CRTC and encoder configuration by calling
  * intel_reserve_dpll_globals() and previously reserved PLLs can be released
  * with intel_release_dpll_globals().
  * Changes to the users are first staged in the atomic state, and then made
  * effective by calling intel_dpll_swap_state() during the atomic
  * commit phase.
@@ -4412,7 +4412,7 @@ int intel_compute_dpll_globals(struct intel_atomic_state *state,
 }
 
 /**
  * intel_reserve_dpll_globals - reserve DPLLs for CRTC and encoder combination
  * @state: atomic state
  * @crtc: CRTC to reserve DPLLs for
  * @encoder: encoder
@@ -4425,15 +4425,15 @@ int intel_compute_dpll_globals(struct intel_atomic_state *state,
  * calling intel_dpll_swap_state().
  *
  * The reserved DPLLs should be released by calling
- * intel_release_dpll_globals().
+ * intel_dpll_release().
  *
  * Returns:
  * 0 if all required DPLLs were successfully reserved,
  * negative error code otherwise.
  */
-int intel_reserve_dpll_globals(struct intel_atomic_state *state,
-			       struct intel_crtc *crtc,
-			       struct intel_encoder *encoder)
+int intel_dpll_reserve(struct intel_atomic_state *state,
+		       struct intel_crtc *crtc,
+		       struct intel_encoder *encoder)
 {
 	struct intel_display *display = to_intel_display(state);
 	const struct intel_dpll_mgr *dpll_mgr = display->dpll.mgr;
@@ -4445,18 +4445,18 @@ int intel_reserve_dpll_globals(struct intel_atomic_state *state,
 }
 
 /**
  * intel_release_dpll_globals - end use of DPLLs by CRTC in atomic state
  * @state: atomic state
  * @crtc: crtc from which the DPLLs are to be released
  *
  * This function releases all DPLLs reserved by intel_reserve_dpll_globals()
  * from the current atomic commit @state and the old @crtc atomic state.
  *
  * The new configuration in the atomic commit @state is made effective by
  * calling intel_dpll_swap_state().
  */
-void intel_release_dpll_globals(struct intel_atomic_state *state,
-				struct intel_crtc *crtc)
+void intel_dpll_release(struct intel_atomic_state *state,
+			struct intel_crtc *crtc)
 {
 	struct intel_display *display = to_intel_display(state);
 	const struct intel_dpll_mgr *dpll_mgr = display->dpll.mgr;
@@ -4464,7 +4464,7 @@ void intel_release_dpll_globals(struct intel_atomic_state *state,
 	/*
 	 * FIXME: this function is called for every platform having a
 	 * compute_clock hook, even though the platform doesn't yet support
 	 * the global DPLL framework and intel_reserve_dpll_globals() is not
 	 * called on those.
 	 */
 	if (!dpll_mgr)
@@ -4480,7 +4480,7 @@ void intel_release_dpll_globals(struct intel_atomic_state *state,
  * @encoder: encoder determining the type of port DPLL
  *
  * Update the active DPLL for the given @crtc/@encoder in @crtc's atomic state,
  * from the port DPLLs reserved previously by intel_reserve_dpll_globals(). The
  * DPLL selected will be based on the current mode of the encoder's port.
  */
 void intel_update_active_dpll(struct intel_atomic_state *state,
@@ -53,8 +53,8 @@
  * modset interface. During an atomic operation, required PLLs can be reserved
  * for a given CRTC and encoder configuration by calling
- * intel_reserve_dpll_globals() and previously reserved PLLs can be released
- * with intel_release_dpll_globals().
+ * intel_dpll_reserve() and previously reserved PLLs can be released
+ * with intel_dpll_release().
  * Changes to the users are first staged in the atomic state, and then made
  * effective by calling intel_dpll_swap_state() during the atomic
@@ -4412,7 +4412,7 @@ int intel_compute_dpll_globals(struct intel_atomic_state *state,
 
 /**
- * intel_reserve_dpll_globals - reserve DPLLs for CRTC and encoder combination
+ * intel_dpll_reserve - reserve DPLLs for CRTC and encoder combination
  * @state: atomic state
  * @crtc: CRTC to reserve DPLLs for
@@ -4445,18 +4445,18 @@ int intel_reserve_dpll_globals(struct intel_atomic_state *state,
 
 /**
- * intel_release_dpll_globals - end use of DPLLs by CRTC in atomic state
+ * intel_dpll_release - end use of DPLLs by CRTC in atomic state
  * @state: atomic state
  * @crtc: crtc from which the DPLLs are to be released
@@ -4445,18 +4445,18 @@ int intel_reserve_dpll_globals(struct intel_atomic_state *state,
  * @crtc: crtc from which the DPLLs are to be released
  *
- * This function releases all DPLLs reserved by intel_reserve_dpll_globals()
+ * This function releases all DPLLs reserved by intel_dpll_reserve()
  * from the current atomic commit @state and the old @crtc atomic state.
  *
@@ -4464,7 +4464,7 @@ void intel_release_dpll_globals(struct intel_atomic_state *state,
 	 * FIXME: this function is called for every platform having a
 	 * compute_clock hook, even though the platform doesn't yet support
-	 * the global DPLL framework and intel_reserve_dpll_globals() is not
+	 * the global DPLL framework and intel_dpll_reserve() is not
 	 * called on those.
 	 */
@@ -4480,7 +4480,7 @@ void intel_release_dpll_globals(struct intel_atomic_state *state,
  *
  * Update the active DPLL for the given @crtc/@encoder in @crtc's atomic state,
- * from the port DPLLs reserved previously by intel_reserve_dpll_globals(). The
+ * from the port DPLLs reserved previously by intel_dpll_reserve(). The
  * DPLL selected will be based on the current mode of the encoder's port.
  */